==> phpdoc-0.2.0.tgz: package/README.md <==
# phpdoc

[![Build Status](https://travis-ci.org/rwhogg/phpdoc.svg?branch=master)](https://travis-ci.org/rwhogg/phpdoc)

This is a Node.js-compatible wrapper for [phpdoc](https://github.com/phpDocumentor/phpDocumentor2).

## Installing
Add phpdoc as a dev (probably) dependency:

```bash
$ npm install --save-dev phpdoc;
```

## Usage

Currently only the "run" command is supported.

```js
var PHPDoc = require("phpdoc.js");
var phpdoc = new PHPDoc("<path/to/phpdoc>");
phpdoc.run([["-d", "<output location>"]]);
```

Note that you _must_ have phpdoc available already in order to use this module.
If you don't, you can do something like the following (using [bin-wrapper](https://github.com/kevva/bin-wrapper)):

```js
var path = require("path");
var BinWrapper = require("bin-wrapper");
var phpdocBin = new BinWrapper()
    .src("http://phpdoc.org/phpDocumentor.phar")
    .dest(path.join("phpdoc"))
    .use("phpDocumentor.phar");
phpdocBin.run(["--version"], function()
{
    var phpdoc = new PHPDoc(phpdocBin.path());
    // do what you want with it...
});
```

## License
Copyright © 2015 Bob W. Hogg. All Rights Reserved.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

==> phpdoc-0.3.0.tgz: package/README.md <==
# phpdoc

[![Build Status](https://travis-ci.org/rwhogg/phpdoc.svg?branch=master)](https://travis-ci.org/rwhogg/phpdoc)

This is a Node.js-compatible wrapper for [phpdoc](https://github.com/phpDocumentor/phpDocumentor2).

## Installing
Add phpdoc as a dev (probably) dependency:

```bash
$ npm install --save-dev phpdoc;
```

## Usage

Currently only the "run" command is supported.

```js
var PHPDoc = require("phpdoc");
var phpdoc = new PHPDoc("<path/to/phpdoc>");
phpdoc.run([["-d", "<directories>", "-t", "<output location>"]]);
```

Note that you _must_ have phpdoc available already in order to use this module.
If you don't, you can do something like the following (using [bin-wrapper](https://github.com/kevva/bin-wrapper)):

```js
var path = require("path");
var BinWrapper = require("bin-wrapper");
var phpdocBin = new BinWrapper()
    .src("http://phpdoc.org/phpDocumentor.phar")
    .dest(path.join("phpdoc"))
    .use("phpDocumentor.phar");
phpdocBin.run(["--version"], function()
{
    var phpdoc = new PHPDoc(phpdocBin.path());
    // do what you want with it...
});
```

## License
Copyright © 2015 Bob W. Hogg. All Rights Reserved.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
